CategoricalDomain
=================

.. currentmodule:: pqp.data

.. autoclass:: CategoricalDomain
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~CategoricalDomain.describe_assumptions
      ~CategoricalDomain.get_cardinality
      ~CategoricalDomain.get_values

   .. rubric:: Methods Documentation

   .. automethod:: describe_assumptions
   .. automethod:: get_cardinality
   .. automethod:: get_values
